@@ -54,9 +54,10 @@ func NewReverseProxy(target *url.URL, upstreamFlush time.Duration, rootCAs []str
 	proxy.FlushInterval = upstreamFlush
 
 	transport := &http.Transport{
-		MaxIdleConns:          1000,
-		MaxIdleConnsPerHost:   500,
-		IdleConnTimeout:       1 * time.Minute,
+		MaxConnsPerHost:       25,
+		MaxIdleConns:          25,
+		MaxIdleConnsPerHost:   25,
+		IdleConnTimeout:       60 * time.Second,
 		TLSHandshakeTimeout:   10 * time.Second,
 		ExpectContinueTimeout: 1 * time.Second,
 	}
